@@ -1,11 +1,21 @@
 #' Plot Interval Scatterplot
 #'
-#' @param x value
-#' @param y value
-#' @param sym.data value
-#' @param pos.var value
+#' @param x symbolic table with only one column.
+#' @param y symbolic table with only one column.
+#' @param sym.data original symbolic table.
+#' @param pos.var column number of the variables to be plotted.
 #'
-cfa.scatterplot.gg <- function(x,y, sym.data, pos.var) {
+#' @examples
+#' data("ex_mcfa1")
+#' sym.table <- classic.to.sym(ex_mcfa1, concept = "suspect",
+#'                    variables.types = c(hair = type.set(),
+#'                                        eyes = type.set(),
+#'                                        region = type.set()))
+#'
+#' res <- sym.mcfa(sym.table, c(1,2))
+#' mcfa.scatterplot(res[,1], res[,2], sym.data = sym.table, pos.var = c(1,2))
+
+mcfa.scatterplot <- function(x,y, sym.data, pos.var) {
   var.names <- c()
   n.vars <- c()
   for (i in pos.var) {
