@@ -4,6 +4,29 @@
 #' @keywords datasets
 "table7"
 
+#' @name ex_mcfa1
+#' @title ex_mcfa1
+#' @description example for the sym.mcfa function.
+#' @example
+#' #' @examples
+#' data("ex_mcfa1")
+#' sym.table <- classic.to.sym(ex_mcfa1, concept = "suspect",
+#'                    variables.types = c(hair = type.set(),
+#'                                        eyes = type.set(),
+#'                                        region = type.set()))
+#'
+#' res <- sym.mcfa(sym.table, c(1,2))
+#' mcfa.scatterplot(res[,1], res[,2], sym.data = sym.table, pos.var = c(1,2))
+#'
+#' @keywords datasets
+"ex_mcfa1"
+
+#' @name ex_mcfa2
+#' @title ex_mcfa2
+#' @description example for the sym.mcfa function.
+#' @keywords datasets
+"ex_mcfa2"
+
 
 #' @name abalone
 #' @title SODAS XML data file.
